//=============================================================================
// Project:    SLP - An Interpreter for Super Logic Programs / Static Semantics
// Module:     in.h
// Purpose:    Abstract Input Source (e.g. File, CGI, Keyboard)
// Last Change:29.03.2001
// Language:   C++
// Author:     Stefan Brass
// Email:      Stefan.Brass@informatik.uni-giessen.de, sbrass@sis.pitt.edu
// Address:    Universitaet Giessen, Arndtstr. 2, 35392 Giessen, Germany
// Copyright:  (c) 1998-2001 by Stefan Brass
// Licence:    Distributed under the conditions of the GNU Public Licence.
//=============================================================================

//=============================================================================
// Include File Frame:
//=============================================================================

#ifndef	IN_INCLUDED
#define IN_INCLUDED

//=============================================================================
// Used Types and Macros:
//=============================================================================

#ifndef BOOL_INCLUDED
#include "bool.h"
#endif

#ifndef STR_INCLUDED
#include "str.h"
#endif

#ifndef CHECK_INCLUDED
#include "check.h"
#endif

//=============================================================================
// Class for Input Source:
//=============================================================================

class in_c {
	public:

//-----------------------------------------------------------------------------
// Destructor:
//-----------------------------------------------------------------------------

	virtual inline ~in_c(void)
		{};

//-----------------------------------------------------------------------------
// read: Read characters from input file into buffer.
//-----------------------------------------------------------------------------

	virtual int	read(char *buf, int size) = 0;

//-----------------------------------------------------------------------------
// is_open: This is really an open input stream (i.e. opening was successful).
//-----------------------------------------------------------------------------

	virtual bool_t	is_open(void) = 0;

//-----------------------------------------------------------------------------
// close: Close input file explicitly.
//-----------------------------------------------------------------------------

	virtual bool_t	close(void) = 0;

//-----------------------------------------------------------------------------
// filename: Name of this file (if it is a file).
//-----------------------------------------------------------------------------

	virtual str_t	filename(void) = 0;

//=============================================================================
// End of Class:
//=============================================================================

};

//-----------------------------------------------------------------------------
// Define pointer type:
//-----------------------------------------------------------------------------

typedef in_c *in_t;

//=============================================================================
// Exported Constants:
//=============================================================================

//-----------------------------------------------------------------------------
// IN_NIL: Null pointer to file class.
//-----------------------------------------------------------------------------

static in_c * const IN_NIL = 0;

//=============================================================================
// End of File:
//=============================================================================

#endif

